@@ -1,10 +1,13 @@
 import json
 import time
+import logging
 
 from .alert import Alert
 from .entity import Entity
 from .helpers import to_unix_time
 
+logger = logging.getLogger(__name__)
+
 
 class Device(Entity):
 
@@ -208,7 +211,7 @@ class Device(Entity):
             if result is None or len(result["messages"]) == 0:
                 return
 
-            print("fetched %d of %d messages" % (
+            logger.debug("fetched %d of %d messages" % (
                 result.get("returned_num_messages", -1), result.get("requested_num_messages", -1)
             ))
 
@@ -216,7 +219,7 @@ class Device(Entity):
                 return
 
             for item in result.get("messages", {}):
-                print("item: ", item)
+                logger.debug("item: ", item)
                 yield item
 
             if direction == "forward":
